@@ -350,6 +350,8 @@ flatpak_complete_search (FlatpakCompletion *completion)
     return FALSE;
 
   flatpak_complete_options (completion, global_entries);
+  flatpak_complete_options (completion, options);
   flatpak_complete_options (completion, user_entries);
+  flatpak_complete_columns (completion, all_columns);
   return TRUE;
 }
