@@ -25,8 +25,11 @@
 #include <gio/gio.h>
 
 #include "flatpak-complete.h"
+#include "flatpak-tty-utils-private.h"
 #include "flatpak-utils-private.h"
 #include "flatpak-dir-private.h"
+#include "flatpak-dir-utils-private.h"
+#include "flatpak-xml-utils-private.h"
 
 G_BEGIN_DECLS
 
